# pypi-template 

[![Custom shields.io](https://img.shields.io/badge/docs-brightgreen?logo=github&logoColor=green&label=gh-pages)](https://lonelyneutrin0.github.io/pypi-template/)
[![PyPI version shields.io](https://img.shields.io/pypi/v/neurop.svg)](https://pypi.python.org/pypi/pypi-template/)
[![PyPI pyversions shields.io](https://img.shields.io/pypi/pyversions/neurop.svg)](https://pypi.python.org/pypi/pypi-template/)

## About varidock
Docking automation.

## Usage
```
pip install varidock
```

## License
`pypi-template` is available under the MIT License.

## Attribution

## Contributing